@@ -26,7 +26,7 @@ def cli():
                 print(''.join([str(i + 1), ':', ecses[i].__str__()]))
 
             indexstr = input('请选择ECS序号:')
-            if not isinstance(indexstr, int):
+            if not indexstr.isdigit():
                 continue
             if int(indexstr) > len(ecses):
                 continue
@@ -38,6 +38,13 @@ def cli():
             os.system('ssh ' + sship)
         except SyntaxError as e:
             pass
+        except SyntaxError as e:
+            try:
+                logging.error(e.msg, e)
+            except:
+                pass
+            pass
+
 
 
 if __name__ == '__main__':
